==> pcre-8.36-x86_64-1.txz: install/doinst.sh <==
( cd usr/man/man3 ; rm -rf pcre32_free_substring_list.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_substring_list.3.gz pcre32_free_substring_list.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_get_stringnumber.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_stringnumber.3.gz pcre16_get_stringnumber.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_free_substring_list.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_substring_list.3.gz pcre16_free_substring_list.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_refcount.3.gz )
( cd usr/man/man3 ; ln -sf pcre_refcount.3.gz pcre16_refcount.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_fullinfo.3.gz )
( cd usr/man/man3 ; ln -sf pcre_fullinfo.3.gz pcre32_fullinfo.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_copy_named_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_copy_named_substring.3.gz pcre16_copy_named_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_compile.3.gz )
( cd usr/man/man3 ; ln -sf pcre_compile.3.gz pcre16_compile.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_get_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_substring.3.gz pcre32_get_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_copy_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_copy_substring.3.gz pcre16_copy_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_utf16_to_host_byte_order.3.gz )
( cd usr/man/man3 ; ln -sf pcre_utf16_to_host_byte_order.3.gz pcre16_utf16_to_host_byte_order.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_get_named_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_named_substring.3.gz pcre32_get_named_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_assign_jit_stack.3.gz )
( cd usr/man/man3 ; ln -sf pcre_assign_jit_stack.3.gz pcre32_assign_jit_stack.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_copy_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_copy_substring.3.gz pcre32_copy_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_utf32_to_host_byte_order.3.gz )
( cd usr/man/man3 ; ln -sf pcre_utf32_to_host_byte_order.3.gz pcre32_utf32_to_host_byte_order.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_get_stringtable_entries.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_stringtable_entries.3.gz pcre16_get_stringtable_entries.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_compile.3.gz )
( cd usr/man/man3 ; ln -sf pcre_compile.3.gz pcre32_compile.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_get_substring_list.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_substring_list.3.gz pcre16_get_substring_list.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_version.3.gz )
( cd usr/man/man3 ; ln -sf pcre_version.3.gz pcre16_version.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_get_substring_list.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_substring_list.3.gz pcre32_get_substring_list.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_dfa_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_dfa_exec.3.gz pcre16_dfa_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_study.3.gz )
( cd usr/man/man3 ; ln -sf pcre_study.3.gz pcre32_study.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_version.3.gz )
( cd usr/man/man3 ; ln -sf pcre_version.3.gz pcre32_version.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_free_study.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_study.3.gz pcre32_free_study.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_get_stringnumber.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_stringnumber.3.gz pcre32_get_stringnumber.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_config.3.gz )
( cd usr/man/man3 ; ln -sf pcre_config.3.gz pcre32_config.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_get_stringtable_entries.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_stringtable_entries.3.gz pcre32_get_stringtable_entries.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_jit_stack_alloc.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_stack_alloc.3.gz pcre16_jit_stack_alloc.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_free_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_substring.3.gz pcre16_free_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_copy_named_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_copy_named_substring.3.gz pcre32_copy_named_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_maketables.3.gz )
( cd usr/man/man3 ; ln -sf pcre_maketables.3.gz pcre32_maketables.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_compile2.3.gz )
( cd usr/man/man3 ; ln -sf pcre_compile2.3.gz pcre32_compile2.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_fullinfo.3.gz )
( cd usr/man/man3 ; ln -sf pcre_fullinfo.3.gz pcre16_fullinfo.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_dfa_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_dfa_exec.3.gz pcre32_dfa_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_config.3.gz )
( cd usr/man/man3 ; ln -sf pcre_config.3.gz pcre16_config.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_exec.3.gz pcre16_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_pattern_to_host_byte_order.3.gz )
( cd usr/man/man3 ; ln -sf pcre_pattern_to_host_byte_order.3.gz pcre32_pattern_to_host_byte_order.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_get_named_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_named_substring.3.gz pcre16_get_named_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_refcount.3.gz )
( cd usr/man/man3 ; ln -sf pcre_refcount.3.gz pcre32_refcount.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_jit_stack_free.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_stack_free.3.gz pcre32_jit_stack_free.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_jit_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_exec.3.gz pcre16_jit_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_jit_stack_free.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_stack_free.3.gz pcre16_jit_stack_free.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_maketables.3.gz )
( cd usr/man/man3 ; ln -sf pcre_maketables.3.gz pcre16_maketables.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_get_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_substring.3.gz pcre16_get_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_exec.3.gz pcre32_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_free_study.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_study.3.gz pcre16_free_study.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_compile2.3.gz )
( cd usr/man/man3 ; ln -sf pcre_compile2.3.gz pcre16_compile2.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_pattern_to_host_byte_order.3.gz )
( cd usr/man/man3 ; ln -sf pcre_pattern_to_host_byte_order.3.gz pcre16_pattern_to_host_byte_order.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_jit_stack_alloc.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_stack_alloc.3.gz pcre32_jit_stack_alloc.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_assign_jit_stack.3.gz )
( cd usr/man/man3 ; ln -sf pcre_assign_jit_stack.3.gz pcre16_assign_jit_stack.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_jit_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_exec.3.gz pcre32_jit_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_study.3.gz )
( cd usr/man/man3 ; ln -sf pcre_study.3.gz pcre16_study.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_free_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_substring.3.gz pcre32_free_substring.3.gz )
( cd usr/lib64 ; rm -rf libpcre32.so )
( cd usr/lib64 ; ln -sf libpcre32.so.0.0.4 libpcre32.so )
( cd usr/lib64 ; rm -rf libpcre.so )
( cd usr/lib64 ; ln -sf libpcre.so.1.2.4 libpcre.so )
( cd usr/lib64 ; rm -rf libpcre.so.1 )
( cd usr/lib64 ; ln -sf libpcre.so.1.2.4 libpcre.so.1 )
( cd usr/lib64 ; rm -rf libpcre16.so.0 )
( cd usr/lib64 ; ln -sf libpcre16.so.0.2.4 libpcre16.so.0 )
( cd usr/lib64 ; rm -rf libpcrecpp.so )
( cd usr/lib64 ; ln -sf libpcrecpp.so.0.0.1 libpcrecpp.so )
( cd usr/lib64 ; rm -rf libpcrecpp.so.0 )
( cd usr/lib64 ; ln -sf libpcrecpp.so.0.0.1 libpcrecpp.so.0 )
( cd usr/lib64 ; rm -rf libpcre16.so )
( cd usr/lib64 ; ln -sf libpcre16.so.0.2.4 libpcre16.so )
( cd usr/lib64 ; rm -rf libpcreposix.so.0 )
( cd usr/lib64 ; ln -sf libpcreposix.so.0.0.3 libpcreposix.so.0 )
( cd usr/lib64 ; rm -rf libpcre32.so.0 )
( cd usr/lib64 ; ln -sf libpcre32.so.0.0.4 libpcre32.so.0 )
( cd usr/lib64 ; rm -rf libpcreposix.so )
( cd usr/lib64 ; ln -sf libpcreposix.so.0.0.3 libpcreposix.so )

==> pcre-8.37-x86_64-1.txz: install/doinst.sh <==
( cd lib64 ; rm -rf libpcre.so.1 )
( cd lib64 ; ln -sf libpcre.so.1.2.5 libpcre.so.1 )
( cd lib64 ; rm -rf libpcre16.so.0 )
( cd lib64 ; ln -sf libpcre16.so.0.2.5 libpcre16.so.0 )
( cd lib64 ; rm -rf libpcrecpp.so.0 )
( cd lib64 ; ln -sf libpcrecpp.so.0.0.1 libpcrecpp.so.0 )
( cd lib64 ; rm -rf libpcreposix.so.0 )
( cd lib64 ; ln -sf libpcreposix.so.0.0.3 libpcreposix.so.0 )
( cd lib64 ; rm -rf libpcre32.so.0 )
( cd lib64 ; ln -sf libpcre32.so.0.0.5 libpcre32.so.0 )
( cd usr/man/man3 ; rm -rf pcre32_free_substring_list.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_substring_list.3.gz pcre32_free_substring_list.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_get_stringnumber.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_stringnumber.3.gz pcre16_get_stringnumber.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_free_substring_list.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_substring_list.3.gz pcre16_free_substring_list.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_refcount.3.gz )
( cd usr/man/man3 ; ln -sf pcre_refcount.3.gz pcre16_refcount.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_fullinfo.3.gz )
( cd usr/man/man3 ; ln -sf pcre_fullinfo.3.gz pcre32_fullinfo.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_copy_named_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_copy_named_substring.3.gz pcre16_copy_named_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_compile.3.gz )
( cd usr/man/man3 ; ln -sf pcre_compile.3.gz pcre16_compile.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_get_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_substring.3.gz pcre32_get_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_copy_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_copy_substring.3.gz pcre16_copy_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_utf16_to_host_byte_order.3.gz )
( cd usr/man/man3 ; ln -sf pcre_utf16_to_host_byte_order.3.gz pcre16_utf16_to_host_byte_order.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_get_named_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_named_substring.3.gz pcre32_get_named_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_assign_jit_stack.3.gz )
( cd usr/man/man3 ; ln -sf pcre_assign_jit_stack.3.gz pcre32_assign_jit_stack.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_copy_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_copy_substring.3.gz pcre32_copy_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_utf32_to_host_byte_order.3.gz )
( cd usr/man/man3 ; ln -sf pcre_utf32_to_host_byte_order.3.gz pcre32_utf32_to_host_byte_order.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_get_stringtable_entries.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_stringtable_entries.3.gz pcre16_get_stringtable_entries.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_compile.3.gz )
( cd usr/man/man3 ; ln -sf pcre_compile.3.gz pcre32_compile.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_get_substring_list.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_substring_list.3.gz pcre16_get_substring_list.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_version.3.gz )
( cd usr/man/man3 ; ln -sf pcre_version.3.gz pcre16_version.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_get_substring_list.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_substring_list.3.gz pcre32_get_substring_list.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_dfa_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_dfa_exec.3.gz pcre16_dfa_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_study.3.gz )
( cd usr/man/man3 ; ln -sf pcre_study.3.gz pcre32_study.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_version.3.gz )
( cd usr/man/man3 ; ln -sf pcre_version.3.gz pcre32_version.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_free_study.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_study.3.gz pcre32_free_study.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_get_stringnumber.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_stringnumber.3.gz pcre32_get_stringnumber.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_config.3.gz )
( cd usr/man/man3 ; ln -sf pcre_config.3.gz pcre32_config.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_get_stringtable_entries.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_stringtable_entries.3.gz pcre32_get_stringtable_entries.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_jit_stack_alloc.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_stack_alloc.3.gz pcre16_jit_stack_alloc.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_free_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_substring.3.gz pcre16_free_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_copy_named_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_copy_named_substring.3.gz pcre32_copy_named_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_maketables.3.gz )
( cd usr/man/man3 ; ln -sf pcre_maketables.3.gz pcre32_maketables.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_compile2.3.gz )
( cd usr/man/man3 ; ln -sf pcre_compile2.3.gz pcre32_compile2.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_fullinfo.3.gz )
( cd usr/man/man3 ; ln -sf pcre_fullinfo.3.gz pcre16_fullinfo.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_dfa_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_dfa_exec.3.gz pcre32_dfa_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_config.3.gz )
( cd usr/man/man3 ; ln -sf pcre_config.3.gz pcre16_config.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_exec.3.gz pcre16_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_pattern_to_host_byte_order.3.gz )
( cd usr/man/man3 ; ln -sf pcre_pattern_to_host_byte_order.3.gz pcre32_pattern_to_host_byte_order.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_get_named_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_named_substring.3.gz pcre16_get_named_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_refcount.3.gz )
( cd usr/man/man3 ; ln -sf pcre_refcount.3.gz pcre32_refcount.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_jit_stack_free.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_stack_free.3.gz pcre32_jit_stack_free.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_jit_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_exec.3.gz pcre16_jit_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_jit_stack_free.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_stack_free.3.gz pcre16_jit_stack_free.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_maketables.3.gz )
( cd usr/man/man3 ; ln -sf pcre_maketables.3.gz pcre16_maketables.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_get_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_get_substring.3.gz pcre16_get_substring.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_exec.3.gz pcre32_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_free_study.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_study.3.gz pcre16_free_study.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_compile2.3.gz )
( cd usr/man/man3 ; ln -sf pcre_compile2.3.gz pcre16_compile2.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_pattern_to_host_byte_order.3.gz )
( cd usr/man/man3 ; ln -sf pcre_pattern_to_host_byte_order.3.gz pcre16_pattern_to_host_byte_order.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_jit_stack_alloc.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_stack_alloc.3.gz pcre32_jit_stack_alloc.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_assign_jit_stack.3.gz )
( cd usr/man/man3 ; ln -sf pcre_assign_jit_stack.3.gz pcre16_assign_jit_stack.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_jit_exec.3.gz )
( cd usr/man/man3 ; ln -sf pcre_jit_exec.3.gz pcre32_jit_exec.3.gz )
( cd usr/man/man3 ; rm -rf pcre16_study.3.gz )
( cd usr/man/man3 ; ln -sf pcre_study.3.gz pcre16_study.3.gz )
( cd usr/man/man3 ; rm -rf pcre32_free_substring.3.gz )
( cd usr/man/man3 ; ln -sf pcre_free_substring.3.gz pcre32_free_substring.3.gz )
( cd usr/lib64 ; rm -rf libpcre32.so )
( cd usr/lib64 ; ln -sf libpcre32.so.0.0.5 libpcre32.so )
( cd usr/lib64 ; rm -rf libpcre.so )
( cd usr/lib64 ; ln -sf libpcre.so.1.2.5 libpcre.so )
( cd usr/lib64 ; rm -rf libpcre16.so.0.2.5 )
( cd usr/lib64 ; ln -sf ../../lib64/libpcre16.so.0.2.5 libpcre16.so.0.2.5 )
( cd usr/lib64 ; rm -rf libpcre.so.1 )
( cd usr/lib64 ; ln -sf libpcre.so.1.2.5 libpcre.so.1 )
( cd usr/lib64 ; rm -rf libpcre16.so.0 )
( cd usr/lib64 ; ln -sf libpcre16.so.0.2.5 libpcre16.so.0 )
( cd usr/lib64 ; rm -rf libpcrecpp.so )
( cd usr/lib64 ; ln -sf libpcrecpp.so.0.0.1 libpcrecpp.so )
( cd usr/lib64 ; rm -rf libpcrecpp.so.0 )
( cd usr/lib64 ; ln -sf libpcrecpp.so.0.0.1 libpcrecpp.so.0 )
( cd usr/lib64 ; rm -rf libpcre.so.1.2.5 )
( cd usr/lib64 ; ln -sf ../../lib64/libpcre.so.1.2.5 libpcre.so.1.2.5 )
( cd usr/lib64 ; rm -rf libpcre16.so )
( cd usr/lib64 ; ln -sf libpcre16.so.0.2.5 libpcre16.so )
( cd usr/lib64 ; rm -rf libpcreposix.so.0 )
( cd usr/lib64 ; ln -sf libpcreposix.so.0.0.3 libpcreposix.so.0 )
( cd usr/lib64 ; rm -rf libpcrecpp.so.0.0.1 )
( cd usr/lib64 ; ln -sf ../../lib64/libpcrecpp.so.0.0.1 libpcrecpp.so.0.0.1 )
( cd usr/lib64 ; rm -rf libpcre32.so.0 )
( cd usr/lib64 ; ln -sf libpcre32.so.0.0.5 libpcre32.so.0 )
( cd usr/lib64 ; rm -rf libpcreposix.so.0.0.3 )
( cd usr/lib64 ; ln -sf ../../lib64/libpcreposix.so.0.0.3 libpcreposix.so.0.0.3 )
( cd usr/lib64 ; rm -rf libpcreposix.so )
( cd usr/lib64 ; ln -sf libpcreposix.so.0.0.3 libpcreposix.so )
( cd usr/lib64 ; rm -rf libpcre32.so.0.0.5 )
( cd usr/lib64 ; ln -sf ../../lib64/libpcre32.so.0.0.5 libpcre32.so.0.0.5 )
